`ensembleGroups` <-
function(x) 
UseMethod("ensembleGroups")

